svg_parsing library

Classes

SvgSizeData
Stores precomputed size and offset information extracted from an SVG.

Functions

parseStyle(XmlElement elem) List<Code>?
Parses paint styles from an SVG element and returns a list of Code statements to apply to a Paint() object.
parseSvgSizeData(XmlElement svg) SvgSizeData?
Parses the area and offsets from an SVG <svg> element's attributes.